@@ -643,7 +643,7 @@ def compute_extensive_kpis(data_df = None, strat = None):
 
     ytd_kpis = get_kpi(ytd_ohlc_df[[strat]])
 
-    return_ytd_to_date = (current_values['close'] - ytd_values['close'])/ytd_values['close']
+    return_ytd_to_date = (current_values[strat] - ytd_values[strat])/ytd_values[strat]
     results = {}
     results[f'return_ytd'] = return_ytd_to_date
 
@@ -651,7 +651,7 @@ def compute_extensive_kpis(data_df = None, strat = None):
         back_date = data_df.index[-1] + pd.DateOffset(months=-1*nb_month)
 
         past_values = data_df.loc[back_date]
-        return_to_date = (current_values['close'] - past_values['close'])/past_values['close']
+        return_to_date = (current_values[strat] - past_values[strat])/past_values[strat]
         results[f'return_{nb_month}_month'] = return_to_date
 
     past_returns = pd.Series(results)
